/* set-favourite.c generated by valac 0.35.3.10-6b27, the Vala compiler
 * generated from set-favourite.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_SET_FAVOURITE_TESTS (set_favourite_tests_get_type ())
#define SET_FAVOURITE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_FAVOURITE_TESTS, SetFavouriteTests))
#define SET_FAVOURITE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_FAVOURITE_TESTS, SetFavouriteTestsClass))
#define IS_SET_FAVOURITE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_FAVOURITE_TESTS))
#define IS_SET_FAVOURITE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_FAVOURITE_TESTS))
#define SET_FAVOURITE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_FAVOURITE_TESTS, SetFavouriteTestsClass))

typedef struct _SetFavouriteTests SetFavouriteTests;
typedef struct _SetFavouriteTestsClass SetFavouriteTestsClass;
typedef struct _SetFavouriteTestsPrivate SetFavouriteTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SetFavouriteTestsTestSetAliasAsyncData SetFavouriteTestsTestSetAliasAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SetFavouriteTests {
	TrackerTestTestCase parent_instance;
	SetFavouriteTestsPrivate * priv;
};

struct _SetFavouriteTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _SetFavouriteTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _initial_fullname_1;
	gchar* _initial_fullname_2;
	gboolean _c1_initially_not_favourite;
	gboolean _c1_finally_favourite;
	gboolean _c2_initially_favourite;
	gboolean _c2_finally_not_favourite;
};

struct _SetFavouriteTestsTestSetAliasAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetFavouriteTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer set_favourite_tests_parent_class = NULL;

GType set_favourite_tests_get_type (void) G_GNUC_CONST;
#define SET_FAVOURITE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_FAVOURITE_TESTS, SetFavouriteTestsPrivate))
enum  {
	SET_FAVOURITE_TESTS_DUMMY_PROPERTY
};
SetFavouriteTests* set_favourite_tests_new (void);
SetFavouriteTests* set_favourite_tests_construct (GType object_type);
void set_favourite_tests_test_set_alias (SetFavouriteTests* self);
static void _set_favourite_tests_test_set_alias_folks_test_case_test_method (gpointer self);
static void _set_favourite_tests_test_set_alias_async (SetFavouriteTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_favourite_tests_test_set_alias_finish (SetFavouriteTests* self, GAsyncResult* _res_);
static void _set_favourite_tests_test_set_alias_async_data_free (gpointer _data);
static gboolean _set_favourite_tests_test_set_alias_async_co (SetFavouriteTestsTestSetAliasAsyncData* _data_);
static void _set_favourite_tests_test_set_alias_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_favourite_tests_individuals_changed_cb (SetFavouriteTests* self, GeeMultiMap* changes);
static void __set_favourite_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _set_favourite_tests_notify_favourite_cb (SetFavouriteTests* self, GObject* individual_obj, GParamSpec* ps);
static void __set_favourite_tests_notify_favourite_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void set_favourite_tests_finalize (GObject * obj);
gint _vala_main (gchar** args, int args_length1);


static void _set_favourite_tests_test_set_alias_folks_test_case_test_method (gpointer self) {
#line 41 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	set_favourite_tests_test_set_alias ((SetFavouriteTests*) self);
#line 122 "set-favourite.c"
}


SetFavouriteTests* set_favourite_tests_construct (GType object_type) {
	SetFavouriteTests * self = NULL;
#line 39 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self = (SetFavouriteTests*) tracker_test_test_case_construct (object_type, "SetFavouriteTests");
#line 41 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test setting favourite ", _set_favourite_tests_test_set_alias_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 37 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	return self;
#line 134 "set-favourite.c"
}


SetFavouriteTests* set_favourite_tests_new (void) {
#line 37 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	return set_favourite_tests_construct (TYPE_SET_FAVOURITE_TESTS);
#line 141 "set-favourite.c"
}


void set_favourite_tests_test_set_alias (SetFavouriteTests* self) {
	GMainLoop* _tmp0_;
	GeeHashMap* c1;
	GeeHashMap* _tmp1_;
	GeeHashMap* c2;
	GeeHashMap* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	TrackerTestBackend* _tmp6_;
	const gchar* _tmp7_;
	TrackerTestBackend* _tmp8_;
	TrackerTestBackend* _tmp9_;
	GMainLoop* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	gboolean _tmp14_;
#line 44 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_return_if_fail (self != NULL);
#line 46 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 46 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 46 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_main_loop = _tmp0_;
#line 47 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 47 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	c1 = _tmp1_;
#line 48 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 48 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	c2 = _tmp2_;
#line 49 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp3_ = g_strdup ("persona #1");
#line 49 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_free0 (self->priv->_initial_fullname_1);
#line 49 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_initial_fullname_1 = _tmp3_;
#line 50 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp4_ = g_strdup ("persona #2");
#line 50 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_free0 (self->priv->_initial_fullname_2);
#line 50 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_initial_fullname_2 = _tmp4_;
#line 52 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp5_ = self->priv->_initial_fullname_1;
#line 52 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp5_);
#line 53 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp6_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 53 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 55 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp7_ = self->priv->_initial_fullname_2;
#line 55 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp7_);
#line 56 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, TRF_ONTOLOGY_DEFS_NAO_TAG, "");
#line 57 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp8_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 57 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c2);
#line 59 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp9_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 59 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 61 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_c1_initially_not_favourite = FALSE;
#line 62 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_c1_finally_favourite = FALSE;
#line 63 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_c2_initially_favourite = FALSE;
#line 64 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_c2_finally_not_favourite = FALSE;
#line 66 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_set_favourite_tests_test_set_alias_async (self, NULL, NULL);
#line 68 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp10_ = self->priv->_main_loop;
#line 68 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	folks_test_utils_loop_run_with_timeout (_tmp10_, 5);
#line 75 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp11_ = self->priv->_c1_initially_not_favourite;
#line 75 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_vala_assert (_tmp11_, "this._c1_initially_not_favourite");
#line 76 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp12_ = self->priv->_c1_finally_favourite;
#line 76 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_vala_assert (_tmp12_, "this._c1_finally_favourite");
#line 77 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp13_ = self->priv->_c2_initially_favourite;
#line 77 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_vala_assert (_tmp13_, "this._c2_initially_favourite");
#line 78 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp14_ = self->priv->_c2_finally_not_favourite;
#line 78 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_vala_assert (_tmp14_, "this._c2_finally_not_favourite");
#line 44 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (c2);
#line 44 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (c1);
#line 247 "set-favourite.c"
}


static void _set_favourite_tests_test_set_alias_async_data_free (gpointer _data) {
	SetFavouriteTestsTestSetAliasAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_slice_free (SetFavouriteTestsTestSetAliasAsyncData, _data_);
#line 258 "set-favourite.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	return self ? g_object_ref (self) : NULL;
#line 265 "set-favourite.c"
}


static void _set_favourite_tests_test_set_alias_async (SetFavouriteTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetFavouriteTestsTestSetAliasAsyncData* _data_;
	SetFavouriteTests* _tmp0_;
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_ = g_slice_new0 (SetFavouriteTestsTestSetAliasAsyncData);
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_favourite_tests_test_set_alias_async);
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_favourite_tests_test_set_alias_async_data_free);
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_set_favourite_tests_test_set_alias_async_co (_data_);
#line 284 "set-favourite.c"
}


static void _set_favourite_tests_test_set_alias_finish (SetFavouriteTests* self, GAsyncResult* _res_) {
	SetFavouriteTestsTestSetAliasAsyncData* _data_;
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 292 "set-favourite.c"
}


static void _set_favourite_tests_test_set_alias_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetFavouriteTestsTestSetAliasAsyncData* _data_;
#line 84 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_ = _user_data_;
#line 84 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->_source_object_ = source_object;
#line 84 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->_res_ = _res_;
#line 84 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_set_favourite_tests_test_set_alias_async_co (_data_);
#line 306 "set-favourite.c"
}


static void __set_favourite_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 86 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_set_favourite_tests_individuals_changed_cb ((SetFavouriteTests*) self, changes);
#line 313 "set-favourite.c"
}


static gboolean _set_favourite_tests_test_set_alias_async_co (SetFavouriteTestsTestSetAliasAsyncData* _data_) {
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	switch (_data_->_state_) {
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		case 0:
#line 322 "set-favourite.c"
		goto _state_0;
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		case 1:
#line 326 "set-favourite.c"
		goto _state_1;
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		case 2:
#line 330 "set-favourite.c"
		goto _state_2;
		default:
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		g_assert_not_reached ();
#line 335 "set-favourite.c"
	}
	_state_0:
#line 83 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 83 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->store = _data_->_tmp0_;
#line 84 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->_state_ = 1;
#line 84 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	folks_backend_store_prepare (_data_->store, _set_favourite_tests_test_set_alias_async_ready, _data_);
#line 84 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	return FALSE;
#line 348 "set-favourite.c"
	_state_1:
#line 84 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 85 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 85 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 85 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 86 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 86 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __set_favourite_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 362 "set-favourite.c"
	{
#line 90 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 90 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_data_->_state_ = 2;
#line 90 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _set_favourite_tests_test_set_alias_async_ready, _data_);
#line 90 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		return FALSE;
#line 372 "set-favourite.c"
		_state_2:
#line 90 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 90 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 378 "set-favourite.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 88 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_data_->e = _data_->_inner_error_;
#line 88 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_data_->_inner_error_ = NULL;
#line 94 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_data_->_tmp4_ = _data_->e;
#line 94 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 94 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		g_warning ("set-favourite.vala:94: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 88 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_g_error_free0 (_data_->e);
#line 397 "set-favourite.c"
	}
	__finally0:
#line 88 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 88 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_g_object_unref0 (_data_->store);
#line 88 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 88 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		g_clear_error (&_data_->_inner_error_);
#line 88 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		return FALSE;
#line 410 "set-favourite.c"
	}
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (_data_->store);
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	if (_data_->_state_ == 0) {
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 418 "set-favourite.c"
	} else {
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 422 "set-favourite.c"
	}
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_object_unref (_data_->_async_result);
#line 81 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	return FALSE;
#line 428 "set-favourite.c"
}


static void __set_favourite_tests_notify_favourite_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 108 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_set_favourite_tests_notify_favourite_cb ((SetFavouriteTests*) self, _sender, pspec);
#line 435 "set-favourite.c"
}


static void _set_favourite_tests_individuals_changed_cb (SetFavouriteTests* self, GeeMultiMap* changes) {
	GeeCollection* added;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_;
	GeeSet* _tmp44_;
	gint _tmp45_;
	gint _tmp46_;
#line 98 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_return_if_fail (self != NULL);
#line 98 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_return_if_fail (changes != NULL);
#line 101 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp0_ = changes;
#line 101 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 101 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	added = _tmp1_;
#line 102 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp2_ = changes;
#line 102 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 102 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	removed = _tmp3_;
#line 465 "set-favourite.c"
	{
		GeeIterator* _i_it;
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_;
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp4_ = added;
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_i_it = _tmp5_;
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		while (TRUE) {
#line 478 "set-favourite.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			FolksIndividual* i;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			FolksIndividual* _tmp12_;
			const gchar* _tmp13_;
			const gchar* _tmp14_;
			const gchar* _tmp15_;
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp6_ = _i_it;
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			if (!_tmp7_) {
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				break;
#line 498 "set-favourite.c"
			}
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp8_ = _i_it;
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			i = (FolksIndividual*) _tmp9_;
#line 106 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp10_ = i;
#line 106 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 108 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp11_ = i;
#line 108 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			g_signal_connect_object ((GObject*) _tmp11_, "notify::is-favourite", (GCallback) __set_favourite_tests_notify_favourite_cb_g_object_notify, self, 0);
#line 109 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp12_ = i;
#line 109 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp13_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp12_);
#line 109 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp14_ = _tmp13_;
#line 109 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp15_ = self->priv->_initial_fullname_1;
#line 109 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			if (g_strcmp0 (_tmp14_, _tmp15_) == 0) {
#line 524 "set-favourite.c"
				FolksIndividual* _tmp16_;
				gboolean _tmp17_;
				gboolean _tmp18_;
#line 111 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				_tmp16_ = i;
#line 111 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				_tmp17_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp16_);
#line 111 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				_tmp18_ = _tmp17_;
#line 111 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				if (_tmp18_ == FALSE) {
#line 113 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
					self->priv->_c1_initially_not_favourite = TRUE;
#line 538 "set-favourite.c"
					{
						GeeIterator* _p_it;
						FolksIndividual* _tmp19_;
						GeeSet* _tmp20_;
						GeeSet* _tmp21_;
						GeeIterator* _tmp22_;
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
						_tmp19_ = i;
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
						_tmp20_ = folks_individual_get_personas (_tmp19_);
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
						_tmp21_ = _tmp20_;
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
						_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
						_p_it = _tmp22_;
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
						while (TRUE) {
#line 557 "set-favourite.c"
							GeeIterator* _tmp23_;
							gboolean _tmp24_;
							FolksPersona* p;
							GeeIterator* _tmp25_;
							gpointer _tmp26_;
							FolksPersona* _tmp27_;
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp23_ = _p_it;
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp24_ = gee_iterator_next (_tmp23_);
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							if (!_tmp24_) {
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								break;
#line 572 "set-favourite.c"
							}
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp25_ = _p_it;
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp26_ = gee_iterator_get (_tmp25_);
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							p = (FolksPersona*) _tmp26_;
#line 117 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp27_ = p;
#line 117 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							folks_favourite_details_set_is_favourite (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, FOLKS_TYPE_FAVOURITE_DETAILS, FolksFavouriteDetails), TRUE);
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_g_object_unref0 (p);
#line 586 "set-favourite.c"
						}
#line 115 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
						_g_object_unref0 (_p_it);
#line 590 "set-favourite.c"
					}
				}
			} else {
				FolksIndividual* _tmp28_;
				const gchar* _tmp29_;
				const gchar* _tmp30_;
				const gchar* _tmp31_;
#line 121 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				_tmp28_ = i;
#line 121 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				_tmp29_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp28_);
#line 121 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				_tmp30_ = _tmp29_;
#line 121 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				_tmp31_ = self->priv->_initial_fullname_2;
#line 121 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				if (g_strcmp0 (_tmp30_, _tmp31_) == 0) {
#line 608 "set-favourite.c"
					FolksIndividual* _tmp32_;
					gboolean _tmp33_;
					gboolean _tmp34_;
#line 123 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
					_tmp32_ = i;
#line 123 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
					_tmp33_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp32_);
#line 123 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
					_tmp34_ = _tmp33_;
#line 123 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
					if (_tmp34_ == TRUE) {
#line 125 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
						self->priv->_c2_initially_favourite = TRUE;
#line 622 "set-favourite.c"
						{
							GeeIterator* _p_it;
							FolksIndividual* _tmp35_;
							GeeSet* _tmp36_;
							GeeSet* _tmp37_;
							GeeIterator* _tmp38_;
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp35_ = i;
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp36_ = folks_individual_get_personas (_tmp35_);
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp37_ = _tmp36_;
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_tmp38_ = gee_iterable_iterator ((GeeIterable*) _tmp37_);
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_p_it = _tmp38_;
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							while (TRUE) {
#line 641 "set-favourite.c"
								GeeIterator* _tmp39_;
								gboolean _tmp40_;
								FolksPersona* p;
								GeeIterator* _tmp41_;
								gpointer _tmp42_;
								FolksPersona* _tmp43_;
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								_tmp39_ = _p_it;
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								_tmp40_ = gee_iterator_next (_tmp39_);
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								if (!_tmp40_) {
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
									break;
#line 656 "set-favourite.c"
								}
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								_tmp41_ = _p_it;
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								_tmp42_ = gee_iterator_get (_tmp41_);
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								p = (FolksPersona*) _tmp42_;
#line 129 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								_tmp43_ = p;
#line 129 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								folks_favourite_details_set_is_favourite (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, FOLKS_TYPE_FAVOURITE_DETAILS, FolksFavouriteDetails), FALSE);
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
								_g_object_unref0 (p);
#line 670 "set-favourite.c"
							}
#line 127 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
							_g_object_unref0 (_p_it);
#line 674 "set-favourite.c"
						}
					}
				}
			}
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_g_object_unref0 (i);
#line 681 "set-favourite.c"
		}
#line 104 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_g_object_unref0 (_i_it);
#line 685 "set-favourite.c"
	}
#line 135 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp44_ = removed;
#line 135 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp45_ = gee_collection_get_size ((GeeCollection*) _tmp44_);
#line 135 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp46_ = _tmp45_;
#line 135 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_vala_assert (_tmp46_ == 1, "removed.size == 1");
#line 695 "set-favourite.c"
	{
		GeeIterator* _i_it;
		GeeSet* _tmp47_;
		GeeIterator* _tmp48_;
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp47_ = removed;
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp48_ = gee_iterable_iterator ((GeeIterable*) _tmp47_);
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_i_it = _tmp48_;
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		while (TRUE) {
#line 708 "set-favourite.c"
			GeeIterator* _tmp49_;
			gboolean _tmp50_;
			FolksIndividual* i;
			GeeIterator* _tmp51_;
			gpointer _tmp52_;
			FolksIndividual* _tmp53_;
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp49_ = _i_it;
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp50_ = gee_iterator_next (_tmp49_);
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			if (!_tmp50_) {
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				break;
#line 723 "set-favourite.c"
			}
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp51_ = _i_it;
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp52_ = gee_iterator_get (_tmp51_);
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			i = (FolksIndividual*) _tmp52_;
#line 139 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp53_ = i;
#line 139 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_vala_assert (_tmp53_ == NULL, "i == null");
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_g_object_unref0 (i);
#line 737 "set-favourite.c"
		}
#line 137 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_g_object_unref0 (_i_it);
#line 741 "set-favourite.c"
	}
#line 98 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (removed);
#line 98 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (added);
#line 747 "set-favourite.c"
}


static void _set_favourite_tests_notify_favourite_cb (SetFavouriteTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_;
#line 143 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_return_if_fail (self != NULL);
#line 143 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_return_if_fail (individual_obj != NULL);
#line 143 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_return_if_fail (ps != NULL);
#line 145 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp0_ = individual_obj;
#line 145 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 145 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	i = _tmp1_;
#line 146 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp2_ = i;
#line 146 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp3_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp2_);
#line 146 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp4_ = _tmp3_;
#line 146 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp5_ = self->priv->_initial_fullname_1;
#line 146 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 783 "set-favourite.c"
		FolksIndividual* _tmp6_;
		gboolean _tmp7_;
		gboolean _tmp8_;
#line 148 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp6_ = i;
#line 148 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp7_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp6_);
#line 148 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp8_ = _tmp7_;
#line 148 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		if (_tmp8_ == TRUE) {
#line 149 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			self->priv->_c1_finally_favourite = TRUE;
#line 797 "set-favourite.c"
		}
	} else {
		FolksIndividual* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
#line 151 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp9_ = i;
#line 151 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp10_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp9_);
#line 151 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp11_ = _tmp10_;
#line 151 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp12_ = self->priv->_initial_fullname_2;
#line 151 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		if (g_strcmp0 (_tmp11_, _tmp12_) == 0) {
#line 814 "set-favourite.c"
			FolksIndividual* _tmp13_;
			gboolean _tmp14_;
			gboolean _tmp15_;
#line 153 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp13_ = i;
#line 153 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp14_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp13_);
#line 153 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			_tmp15_ = _tmp14_;
#line 153 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
			if (_tmp15_ == FALSE) {
#line 154 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
				self->priv->_c2_finally_not_favourite = TRUE;
#line 828 "set-favourite.c"
			}
		}
	}
#line 157 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp17_ = self->priv->_c1_finally_favourite;
#line 157 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	if (_tmp17_) {
#line 836 "set-favourite.c"
		gboolean _tmp18_;
#line 158 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp18_ = self->priv->_c2_finally_not_favourite;
#line 158 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp16_ = _tmp18_;
#line 842 "set-favourite.c"
	} else {
#line 157 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp16_ = FALSE;
#line 846 "set-favourite.c"
	}
#line 157 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	if (_tmp16_) {
#line 850 "set-favourite.c"
		GMainLoop* _tmp19_;
#line 159 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		_tmp19_ = self->priv->_main_loop;
#line 159 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
		g_main_loop_quit (_tmp19_);
#line 856 "set-favourite.c"
	}
#line 143 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (i);
#line 860 "set-favourite.c"
}


static void set_favourite_tests_class_init (SetFavouriteTestsClass * klass) {
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	set_favourite_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_type_class_add_private (klass, sizeof (SetFavouriteTestsPrivate));
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	G_OBJECT_CLASS (klass)->finalize = set_favourite_tests_finalize;
#line 871 "set-favourite.c"
}


static void set_favourite_tests_instance_init (SetFavouriteTests * self) {
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv = SET_FAVOURITE_TESTS_GET_PRIVATE (self);
#line 30 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp0_ = g_strdup ("persona #1");
#line 30 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_initial_fullname_1 = _tmp0_;
#line 31 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp1_ = g_strdup ("persona #2");
#line 31 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self->priv->_initial_fullname_2 = _tmp1_;
#line 888 "set-favourite.c"
}


static void set_favourite_tests_finalize (GObject * obj) {
	SetFavouriteTests * self;
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_FAVOURITE_TESTS, SetFavouriteTests);
#line 28 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_free0 (self->priv->_initial_fullname_1);
#line 31 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_free0 (self->priv->_initial_fullname_2);
#line 26 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	G_OBJECT_CLASS (set_favourite_tests_parent_class)->finalize (obj);
#line 906 "set-favourite.c"
}


GType set_favourite_tests_get_type (void) {
	static volatile gsize set_favourite_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_favourite_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetFavouriteTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_favourite_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetFavouriteTests), 0, (GInstanceInitFunc) set_favourite_tests_instance_init, NULL };
		GType set_favourite_tests_type_id;
		set_favourite_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "SetFavouriteTests", &g_define_type_info, 0);
		g_once_init_leave (&set_favourite_tests_type_id__volatile, set_favourite_tests_type_id);
	}
	return set_favourite_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SetFavouriteTests* tests;
	SetFavouriteTests* _tmp0_;
#line 165 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_test_init (&args_length1, &args, NULL);
#line 167 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_tmp0_ = set_favourite_tests_new ();
#line 167 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	tests = _tmp0_;
#line 168 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 169 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	g_test_run ();
#line 170 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 172 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	result = 0;
#line 172 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	_g_object_unref0 (tests);
#line 172 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	return result;
#line 944 "set-favourite.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 163 "/opt/gnome/source/folks/tests/tracker/set-favourite.vala"
	return _vala_main (argv, argc);
#line 954 "set-favourite.c"
}



