/* favourite-updates.c generated by valac 0.35.3.10-6b27, the Vala compiler
 * generated from favourite-updates.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_FAVOURITE_UPDATES_TESTS (favourite_updates_tests_get_type ())
#define FAVOURITE_UPDATES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FAVOURITE_UPDATES_TESTS, FavouriteUpdatesTests))
#define FAVOURITE_UPDATES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FAVOURITE_UPDATES_TESTS, FavouriteUpdatesTestsClass))
#define IS_FAVOURITE_UPDATES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FAVOURITE_UPDATES_TESTS))
#define IS_FAVOURITE_UPDATES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FAVOURITE_UPDATES_TESTS))
#define FAVOURITE_UPDATES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FAVOURITE_UPDATES_TESTS, FavouriteUpdatesTestsClass))

typedef struct _FavouriteUpdatesTests FavouriteUpdatesTests;
typedef struct _FavouriteUpdatesTestsClass FavouriteUpdatesTestsClass;
typedef struct _FavouriteUpdatesTestsPrivate FavouriteUpdatesTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _FavouriteUpdatesTestsTestFavouriteUpdateAsyncData FavouriteUpdatesTestsTestFavouriteUpdateAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _FavouriteUpdatesTests {
	TrackerTestTestCase parent_instance;
	FavouriteUpdatesTestsPrivate * priv;
};

struct _FavouriteUpdatesTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _FavouriteUpdatesTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gboolean _is_favourite_1;
	gchar* _individual_id_1;
	gboolean _is_favourite_2;
	gchar* _individual_id_2;
	gchar* _initial_fullname_1;
	gchar* _contact_urn_1;
	gchar* _initial_fullname_2;
	gchar* _contact_urn_2;
};

struct _FavouriteUpdatesTestsTestFavouriteUpdateAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FavouriteUpdatesTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer favourite_updates_tests_parent_class = NULL;

GType favourite_updates_tests_get_type (void) G_GNUC_CONST;
#define FAVOURITE_UPDATES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_FAVOURITE_UPDATES_TESTS, FavouriteUpdatesTestsPrivate))
enum  {
	FAVOURITE_UPDATES_TESTS_DUMMY_PROPERTY
};
FavouriteUpdatesTests* favourite_updates_tests_new (void);
FavouriteUpdatesTests* favourite_updates_tests_construct (GType object_type);
void favourite_updates_tests_test_favourite_update (FavouriteUpdatesTests* self);
static void _favourite_updates_tests_test_favourite_update_folks_test_case_test_method (gpointer self);
static void _favourite_updates_tests_test_favourite_update_async (FavouriteUpdatesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _favourite_updates_tests_test_favourite_update_finish (FavouriteUpdatesTests* self, GAsyncResult* _res_);
static void _favourite_updates_tests_test_favourite_update_async_data_free (gpointer _data);
static gboolean _favourite_updates_tests_test_favourite_update_async_co (FavouriteUpdatesTestsTestFavouriteUpdateAsyncData* _data_);
static void _favourite_updates_tests_test_favourite_update_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _favourite_updates_tests_individuals_changed_cb (FavouriteUpdatesTests* self, GeeMultiMap* changes);
static void __favourite_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _favourite_updates_tests_notify_favourite_cb (FavouriteUpdatesTests* self, GObject* individual_obj, GParamSpec* ps);
static void __favourite_updates_tests_notify_favourite_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean ______lambda4_ (FavouriteUpdatesTests* self);
static gboolean _______lambda4__gsource_func (gpointer self);
static void favourite_updates_tests_finalize (GObject * obj);
gint _vala_main (gchar** args, int args_length1);


static void _favourite_updates_tests_test_favourite_update_folks_test_case_test_method (gpointer self) {
#line 43 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	favourite_updates_tests_test_favourite_update ((FavouriteUpdatesTests*) self);
#line 126 "favourite-updates.c"
}


FavouriteUpdatesTests* favourite_updates_tests_construct (GType object_type) {
	FavouriteUpdatesTests * self = NULL;
#line 41 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self = (FavouriteUpdatesTests*) tracker_test_test_case_construct (object_type, "FavouriteUpdates");
#line 43 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "favourite update", _favourite_updates_tests_test_favourite_update_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 39 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return self;
#line 138 "favourite-updates.c"
}


FavouriteUpdatesTests* favourite_updates_tests_new (void) {
#line 39 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return favourite_updates_tests_construct (TYPE_FAVOURITE_UPDATES_TESTS);
#line 145 "favourite-updates.c"
}


void favourite_updates_tests_test_favourite_update (FavouriteUpdatesTests* self) {
	GMainLoop* _tmp0_;
	GeeHashMap* c1;
	GeeHashMap* _tmp1_;
	GeeHashMap* c2;
	GeeHashMap* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	TrackerTestBackend* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	TrackerTestBackend* _tmp12_;
	TrackerTestBackend* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GMainLoop* _tmp16_;
	gboolean _tmp17_;
	gboolean _tmp18_;
#line 46 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_return_if_fail (self != NULL);
#line 48 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 48 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 48 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_main_loop = _tmp0_;
#line 49 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 49 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	c1 = _tmp1_;
#line 50 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 50 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	c2 = _tmp2_;
#line 51 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp3_ = g_strdup ("persona #1");
#line 51 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_initial_fullname_1);
#line 51 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_initial_fullname_1 = _tmp3_;
#line 52 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp4_ = g_strdup ("<urn:contact001>");
#line 52 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_contact_urn_1);
#line 52 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_contact_urn_1 = _tmp4_;
#line 53 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp5_ = g_strdup ("persona #2");
#line 53 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_initial_fullname_2);
#line 53 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_initial_fullname_2 = _tmp5_;
#line 54 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp6_ = g_strdup ("<urn:contact002>");
#line 54 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_contact_urn_2);
#line 54 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_contact_urn_2 = _tmp6_;
#line 56 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp7_ = self->priv->_contact_urn_1;
#line 56 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRACKER_TEST_BACKEND_URN, _tmp7_);
#line 57 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp8_ = self->priv->_initial_fullname_1;
#line 57 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp8_);
#line 58 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp9_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 58 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 60 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp10_ = self->priv->_contact_urn_2;
#line 60 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, TRACKER_TEST_BACKEND_URN, _tmp10_);
#line 61 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp11_ = self->priv->_initial_fullname_2;
#line 61 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp11_);
#line 62 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, TRF_ONTOLOGY_DEFS_NAO_TAG, "");
#line 63 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp12_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 63 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c2);
#line 65 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp13_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 65 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 67 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_is_favourite_1 = FALSE;
#line 68 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp14_ = g_strdup ("");
#line 68 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_individual_id_1);
#line 68 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_individual_id_1 = _tmp14_;
#line 69 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_is_favourite_2 = TRUE;
#line 70 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp15_ = g_strdup ("");
#line 70 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_individual_id_2);
#line 70 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv->_individual_id_2 = _tmp15_;
#line 72 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_favourite_updates_tests_test_favourite_update_async (self, NULL, NULL);
#line 76 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp16_ = self->priv->_main_loop;
#line 76 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	folks_test_utils_loop_run_with_timeout (_tmp16_, 15);
#line 78 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp17_ = self->priv->_is_favourite_1;
#line 78 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_vala_assert (_tmp17_ == TRUE, "this._is_favourite_1 == true");
#line 79 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp18_ = self->priv->_is_favourite_2;
#line 79 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_vala_assert (_tmp18_ == FALSE, "this._is_favourite_2 == false");
#line 46 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (c2);
#line 46 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (c1);
#line 275 "favourite-updates.c"
}


static void _favourite_updates_tests_test_favourite_update_async_data_free (gpointer _data) {
	FavouriteUpdatesTestsTestFavouriteUpdateAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_slice_free (FavouriteUpdatesTestsTestFavouriteUpdateAsyncData, _data_);
#line 286 "favourite-updates.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return self ? g_object_ref (self) : NULL;
#line 293 "favourite-updates.c"
}


static void _favourite_updates_tests_test_favourite_update_async (FavouriteUpdatesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FavouriteUpdatesTestsTestFavouriteUpdateAsyncData* _data_;
	FavouriteUpdatesTests* _tmp0_;
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_ = g_slice_new0 (FavouriteUpdatesTestsTestFavouriteUpdateAsyncData);
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _favourite_updates_tests_test_favourite_update_async);
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _favourite_updates_tests_test_favourite_update_async_data_free);
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_favourite_updates_tests_test_favourite_update_async_co (_data_);
#line 312 "favourite-updates.c"
}


static void _favourite_updates_tests_test_favourite_update_finish (FavouriteUpdatesTests* self, GAsyncResult* _res_) {
	FavouriteUpdatesTestsTestFavouriteUpdateAsyncData* _data_;
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 320 "favourite-updates.c"
}


static void _favourite_updates_tests_test_favourite_update_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FavouriteUpdatesTestsTestFavouriteUpdateAsyncData* _data_;
#line 85 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_ = _user_data_;
#line 85 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->_source_object_ = source_object;
#line 85 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->_res_ = _res_;
#line 85 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_favourite_updates_tests_test_favourite_update_async_co (_data_);
#line 334 "favourite-updates.c"
}


static void __favourite_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 87 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_favourite_updates_tests_individuals_changed_cb ((FavouriteUpdatesTests*) self, changes);
#line 341 "favourite-updates.c"
}


static gboolean _favourite_updates_tests_test_favourite_update_async_co (FavouriteUpdatesTestsTestFavouriteUpdateAsyncData* _data_) {
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	switch (_data_->_state_) {
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		case 0:
#line 350 "favourite-updates.c"
		goto _state_0;
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		case 1:
#line 354 "favourite-updates.c"
		goto _state_1;
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		case 2:
#line 358 "favourite-updates.c"
		goto _state_2;
		default:
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		g_assert_not_reached ();
#line 363 "favourite-updates.c"
	}
	_state_0:
#line 84 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 84 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->store = _data_->_tmp0_;
#line 85 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->_state_ = 1;
#line 85 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	folks_backend_store_prepare (_data_->store, _favourite_updates_tests_test_favourite_update_async_ready, _data_);
#line 85 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return FALSE;
#line 376 "favourite-updates.c"
	_state_1:
#line 85 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 86 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 86 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 86 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 87 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 87 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __favourite_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 390 "favourite-updates.c"
	{
#line 91 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 91 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_data_->_state_ = 2;
#line 91 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _favourite_updates_tests_test_favourite_update_async_ready, _data_);
#line 91 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		return FALSE;
#line 400 "favourite-updates.c"
		_state_2:
#line 91 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 91 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 406 "favourite-updates.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 89 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_data_->e = _data_->_inner_error_;
#line 89 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_data_->_inner_error_ = NULL;
#line 95 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_data_->_tmp4_ = _data_->e;
#line 95 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 95 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		g_warning ("favourite-updates.vala:95: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 89 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_g_error_free0 (_data_->e);
#line 425 "favourite-updates.c"
	}
	__finally0:
#line 89 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 89 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_g_object_unref0 (_data_->store);
#line 89 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 89 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		g_clear_error (&_data_->_inner_error_);
#line 89 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		return FALSE;
#line 438 "favourite-updates.c"
	}
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (_data_->store);
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	if (_data_->_state_ == 0) {
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 446 "favourite-updates.c"
	} else {
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 450 "favourite-updates.c"
	}
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_object_unref (_data_->_async_result);
#line 82 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return FALSE;
#line 456 "favourite-updates.c"
}


static void __favourite_updates_tests_notify_favourite_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 111 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_favourite_updates_tests_notify_favourite_cb ((FavouriteUpdatesTests*) self, _sender, pspec);
#line 463 "favourite-updates.c"
}


static gboolean ______lambda4_ (FavouriteUpdatesTests* self) {
	gboolean result = FALSE;
	TrackerTestBackend* _tmp0_;
	const gchar* _tmp1_;
#line 125 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp0_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 125 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp1_ = self->priv->_contact_urn_2;
#line 125 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	tracker_test_backend_update_favourite (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), _tmp1_, FALSE);
#line 127 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	result = FALSE;
#line 127 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return result;
#line 481 "favourite-updates.c"
}


static gboolean _______lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = ______lambda4_ ((FavouriteUpdatesTests*) self);
#line 123 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return result;
#line 490 "favourite-updates.c"
}


static void _favourite_updates_tests_individuals_changed_cb (FavouriteUpdatesTests* self, GeeMultiMap* changes) {
	GeeCollection* added;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_;
	GeeSet* _tmp31_;
	gint _tmp32_;
	gint _tmp33_;
#line 99 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_return_if_fail (self != NULL);
#line 99 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_return_if_fail (changes != NULL);
#line 102 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp0_ = changes;
#line 102 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 102 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	added = _tmp1_;
#line 103 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp2_ = changes;
#line 103 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 103 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	removed = _tmp3_;
#line 520 "favourite-updates.c"
	{
		GeeIterator* _i_it;
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_;
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp4_ = added;
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_i_it = _tmp5_;
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		while (TRUE) {
#line 533 "favourite-updates.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			FolksIndividual* i;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			const gchar* _tmp14_;
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp6_ = _i_it;
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			if (!_tmp7_) {
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				break;
#line 552 "favourite-updates.c"
			}
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp8_ = _i_it;
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			i = (FolksIndividual*) _tmp9_;
#line 107 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp10_ = i;
#line 107 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 109 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp11_ = i;
#line 109 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 109 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp13_ = _tmp12_;
#line 109 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp14_ = self->priv->_initial_fullname_1;
#line 109 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 574 "favourite-updates.c"
				FolksIndividual* _tmp15_;
				FolksIndividual* _tmp16_;
				const gchar* _tmp17_;
				const gchar* _tmp18_;
				gchar* _tmp19_;
				TrackerTestBackend* _tmp20_;
				const gchar* _tmp21_;
#line 111 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp15_ = i;
#line 111 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				g_signal_connect_object ((GObject*) _tmp15_, "notify::is-favourite", (GCallback) __favourite_updates_tests_notify_favourite_cb_g_object_notify, self, 0);
#line 113 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp16_ = i;
#line 113 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp17_ = folks_individual_get_id (_tmp16_);
#line 113 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp18_ = _tmp17_;
#line 113 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp19_ = g_strdup (_tmp18_);
#line 113 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_g_free0 (self->priv->_individual_id_1);
#line 113 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				self->priv->_individual_id_1 = _tmp19_;
#line 114 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp20_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 114 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp21_ = self->priv->_contact_urn_1;
#line 114 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				tracker_test_backend_update_favourite (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), _tmp21_, TRUE);
#line 604 "favourite-updates.c"
			} else {
				FolksIndividual* _tmp22_;
				const gchar* _tmp23_;
				const gchar* _tmp24_;
				const gchar* _tmp25_;
#line 117 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp22_ = i;
#line 117 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp23_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp22_);
#line 117 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp24_ = _tmp23_;
#line 117 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				_tmp25_ = self->priv->_initial_fullname_2;
#line 117 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				if (g_strcmp0 (_tmp24_, _tmp25_) == 0) {
#line 620 "favourite-updates.c"
					FolksIndividual* _tmp26_;
					FolksIndividual* _tmp27_;
					const gchar* _tmp28_;
					const gchar* _tmp29_;
					gchar* _tmp30_;
#line 119 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					_tmp26_ = i;
#line 119 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					g_signal_connect_object ((GObject*) _tmp26_, "notify::is-favourite", (GCallback) __favourite_updates_tests_notify_favourite_cb_g_object_notify, self, 0);
#line 121 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					_tmp27_ = i;
#line 121 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					_tmp28_ = folks_individual_get_id (_tmp27_);
#line 121 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					_tmp29_ = _tmp28_;
#line 121 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					_tmp30_ = g_strdup (_tmp29_);
#line 121 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					_g_free0 (self->priv->_individual_id_2);
#line 121 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					self->priv->_individual_id_2 = _tmp30_;
#line 123 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
					g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 1, _______lambda4__gsource_func, g_object_ref (self), g_object_unref);
#line 644 "favourite-updates.c"
				}
			}
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_g_object_unref0 (i);
#line 649 "favourite-updates.c"
		}
#line 105 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_g_object_unref0 (_i_it);
#line 653 "favourite-updates.c"
	}
#line 132 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp31_ = removed;
#line 132 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp32_ = gee_collection_get_size ((GeeCollection*) _tmp31_);
#line 132 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp33_ = _tmp32_;
#line 132 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_vala_assert (_tmp33_ == 1, "removed.size == 1");
#line 663 "favourite-updates.c"
	{
		GeeIterator* _i_it;
		GeeSet* _tmp34_;
		GeeIterator* _tmp35_;
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp34_ = removed;
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp35_ = gee_iterable_iterator ((GeeIterable*) _tmp34_);
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_i_it = _tmp35_;
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		while (TRUE) {
#line 676 "favourite-updates.c"
			GeeIterator* _tmp36_;
			gboolean _tmp37_;
			FolksIndividual* i;
			GeeIterator* _tmp38_;
			gpointer _tmp39_;
			FolksIndividual* _tmp40_;
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp36_ = _i_it;
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp37_ = gee_iterator_next (_tmp36_);
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			if (!_tmp37_) {
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
				break;
#line 691 "favourite-updates.c"
			}
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp38_ = _i_it;
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp39_ = gee_iterator_get (_tmp38_);
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			i = (FolksIndividual*) _tmp39_;
#line 136 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp40_ = i;
#line 136 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_vala_assert (_tmp40_ == NULL, "i == null");
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_g_object_unref0 (i);
#line 705 "favourite-updates.c"
		}
#line 134 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_g_object_unref0 (_i_it);
#line 709 "favourite-updates.c"
	}
#line 99 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (removed);
#line 99 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (added);
#line 715 "favourite-updates.c"
}


static void _favourite_updates_tests_notify_favourite_cb (FavouriteUpdatesTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_;
#line 140 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_return_if_fail (self != NULL);
#line 140 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_return_if_fail (individual_obj != NULL);
#line 140 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_return_if_fail (ps != NULL);
#line 142 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp0_ = individual_obj;
#line 142 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 142 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	i = _tmp1_;
#line 143 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp2_ = i;
#line 143 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp3_ = folks_individual_get_id (_tmp2_);
#line 143 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp4_ = _tmp3_;
#line 143 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp5_ = self->priv->_individual_id_1;
#line 143 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 751 "favourite-updates.c"
		FolksIndividual* _tmp6_;
		gboolean _tmp7_;
		gboolean _tmp8_;
#line 145 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp6_ = i;
#line 145 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp7_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp6_);
#line 145 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp8_ = _tmp7_;
#line 145 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		self->priv->_is_favourite_1 = _tmp8_;
#line 763 "favourite-updates.c"
	} else {
		FolksIndividual* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
#line 147 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp9_ = i;
#line 147 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp10_ = folks_individual_get_id (_tmp9_);
#line 147 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp11_ = _tmp10_;
#line 147 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp12_ = self->priv->_individual_id_2;
#line 147 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		if (g_strcmp0 (_tmp11_, _tmp12_) == 0) {
#line 779 "favourite-updates.c"
			FolksIndividual* _tmp13_;
			gboolean _tmp14_;
			gboolean _tmp15_;
#line 149 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp13_ = i;
#line 149 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp14_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp13_);
#line 149 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			_tmp15_ = _tmp14_;
#line 149 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
			self->priv->_is_favourite_2 = _tmp15_;
#line 791 "favourite-updates.c"
		}
	}
#line 152 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp17_ = self->priv->_is_favourite_1;
#line 152 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	if (_tmp17_ == TRUE) {
#line 798 "favourite-updates.c"
		gboolean _tmp18_;
#line 153 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp18_ = self->priv->_is_favourite_2;
#line 153 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp16_ = _tmp18_ == FALSE;
#line 804 "favourite-updates.c"
	} else {
#line 152 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp16_ = FALSE;
#line 808 "favourite-updates.c"
	}
#line 152 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	if (_tmp16_) {
#line 812 "favourite-updates.c"
		GMainLoop* _tmp19_;
#line 154 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		_tmp19_ = self->priv->_main_loop;
#line 154 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
		g_main_loop_quit (_tmp19_);
#line 818 "favourite-updates.c"
	}
#line 140 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (i);
#line 822 "favourite-updates.c"
}


static void favourite_updates_tests_class_init (FavouriteUpdatesTestsClass * klass) {
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	favourite_updates_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_type_class_add_private (klass, sizeof (FavouriteUpdatesTestsPrivate));
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	G_OBJECT_CLASS (klass)->finalize = favourite_updates_tests_finalize;
#line 833 "favourite-updates.c"
}


static void favourite_updates_tests_instance_init (FavouriteUpdatesTests * self) {
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self->priv = FAVOURITE_UPDATES_TESTS_GET_PRIVATE (self);
#line 840 "favourite-updates.c"
}


static void favourite_updates_tests_finalize (GObject * obj) {
	FavouriteUpdatesTests * self;
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_FAVOURITE_UPDATES_TESTS, FavouriteUpdatesTests);
#line 28 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_individual_id_1);
#line 33 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_individual_id_2);
#line 34 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_initial_fullname_1);
#line 35 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_contact_urn_1);
#line 36 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_initial_fullname_2);
#line 37 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_free0 (self->priv->_contact_urn_2);
#line 26 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	G_OBJECT_CLASS (favourite_updates_tests_parent_class)->finalize (obj);
#line 866 "favourite-updates.c"
}


GType favourite_updates_tests_get_type (void) {
	static volatile gsize favourite_updates_tests_type_id__volatile = 0;
	if (g_once_init_enter (&favourite_updates_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FavouriteUpdatesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) favourite_updates_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FavouriteUpdatesTests), 0, (GInstanceInitFunc) favourite_updates_tests_instance_init, NULL };
		GType favourite_updates_tests_type_id;
		favourite_updates_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "FavouriteUpdatesTests", &g_define_type_info, 0);
		g_once_init_leave (&favourite_updates_tests_type_id__volatile, favourite_updates_tests_type_id);
	}
	return favourite_updates_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	FavouriteUpdatesTests* tests;
	FavouriteUpdatesTests* _tmp0_;
#line 160 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_test_init (&args_length1, &args, NULL);
#line 162 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_tmp0_ = favourite_updates_tests_new ();
#line 162 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	tests = _tmp0_;
#line 163 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 164 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	g_test_run ();
#line 165 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 167 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	result = 0;
#line 167 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	_g_object_unref0 (tests);
#line 167 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return result;
#line 904 "favourite-updates.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 158 "/opt/gnome/source/folks/tests/tracker/favourite-updates.vala"
	return _vala_main (argv, argc);
#line 914 "favourite-updates.c"
}



